@@ -151,7 +151,7 @@ class Debugger(bdb.Bdb):
         self.curindex = index
         self.curframe, lineno = self.stack[index]
         self.ui.set_current_line(lineno, self.curframe.f_code.co_filename)
-        self.ui.update_var_view(self.curframe.f_locals)
+        self.ui.update_var_view()
         self.ui.update_stack()
 
     def get_shortened_stack(self, frame, tb):
@@ -881,11 +881,15 @@ class DebuggerUI(FrameVarInfoKeeper):
                     [curframe.f_locals, curframe.f_globals],
                     curframe.f_locals)
 
+            if HAVE_READLINE:
+                readline.set_completer(
+                        rlcompleter.Completer(loc).complete)
+
             cons = InteractiveConsole(loc)
             cons.interact(banner)
             self.screen.start()
 
-            self.update_var_view(curframe.f_locals)
+            self.update_var_view()
 
         class RHColumnFocuser:
             def __init__(self, idx):
@@ -952,7 +956,8 @@ class DebuggerUI(FrameVarInfoKeeper):
                 [("OK", True)], title=title, **kwargs)
 
     def dialog(self, content, buttons_and_results,
-            title=None, bind_enter_esc=True, focus_buttons=False):
+            title=None, bind_enter_esc=True, focus_buttons=False,
+            extra_bindings=[]):
         class ResultSetter:
             def __init__(subself, res):
                 subself.res = res
@@ -995,6 +1000,10 @@ class DebuggerUI(FrameVarInfoKeeper):
                 ("fixed", 1, urwid.SolidFill()),
                 w])
 
+        w = SignalWrap(w)
+        for key, binding in extra_bindings:
+            w.listen(key, binding)
+
         w = urwid.LineBox(w)
 
         w = urwid.Overlay(w, self.top,
@@ -1164,14 +1173,16 @@ class DebuggerUI(FrameVarInfoKeeper):
             self.current_line = self.source[line]
             self.current_line.set_current(True)
 
-    def update_var_view(self, locals=None):
+    def update_var_view(self, locals=None, globals=None):
         if locals is None:
             locals = self.debugger.curframe.f_locals
+        if globals is None:
+            globals = self.debugger.curframe.f_globals
 
         from pudb.var_view import make_var_view
         self.locals[:] = make_var_view(
                 self.get_frame_var_info(read_only=True),
-                locals)
+                locals, globals)
 
     def _get_bp_list(self):
         return [bp
